==> kadu_1.2.orig.tar.bz2: kadu-1.2/plugins/firewall/translations/firewall_pl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pl" version="2.0">
<context>
    <name>@default</name>
    <message>
        <source>Firewall</source>
        <translation>Firewall</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Ogólne</translation>
    </message>
    <message>
        <source>Notification syntax</source>
        <translation>Składnia powiadomienia</translation>
    </message>
    <message>
        <source>%u - uin, %m - message</source>
        <translation>%u - uin, %m - wiadomość</translation>
    </message>
    <message>
        <source>Search for unknown person in directory and show window with his personal data.</source>
        <translation>Szukaj nieznanej osoby w katalogu i wyświetlaj okno z informacją o niej.</translation>
    </message>
    <message>
        <source>Unknown chats protection</source>
        <translation>Ochrona przed nieznanymi osobami</translation>
    </message>
    <message>
        <source>Ignore conferences with all persons unknown</source>
        <translation>Ignoruj konferencje, jeśli wszystkie osoby są nieznane</translation>
    </message>
    <message>
        <source>Protect against chats with unknown persons</source>
        <translation>Chroń przed rozmowami z nieznaną osobą</translation>
    </message>
    <message>
        <source>Automatic question</source>
        <translation>Automatyczne pytanie</translation>
    </message>
    <message>
        <source>Send confirmation</source>
        <translation>Wyślij potwierdzenie</translation>
    </message>
    <message>
        <source>Confirmation</source>
        <translation>Potwierdzenie</translation>
    </message>
    <message>
        <source>Safe sending</source>
        <translation>Bezpieczne wysyłanie</translation>
    </message>
    <message>
        <source>Enable safe sending</source>
        <translation>Włącz bezpieczne wysyłanie</translation>
    </message>
    <message>
        <source>You must confirm each message sent to these people</source>
        <translation>Musisz potwierdzić chęć wysłania wiadomości do tych osób</translation>
    </message>
    <message>
        <source>Message was firewalled</source>
        <translation>Wiadomość została zablokowana</translation>
    </message>
    <message>
        <source>Anonymous chat attempt</source>
        <translation>Próba nawiązania rozmowy przez anonima</translation>
    </message>
    <message>
        <source>Save anonymous chat attempt in history</source>
        <translation>Zapisuj próby nawiązania rozmowy przez anonimów w historii</translation>
    </message>
    <message>
        <source>Save anonymous chat attempt in log file</source>
        <translation>Zapisuj próby nawiązania rozmowy przez anonimów w pliku logu</translation>
    </message>
    <message>
        <source>Log file path</source>
        <translation>Ścieżka pliku logu</translation>
    </message>
    <message>
        <source>Kadu will ask the question typed below, if someone wants talk to you and you do not have him on your list.</source>
        <translation>Kadu zada poniższe pytanie osobie próbującej nawiązać rozmowę, jeżeli nie masz jej na liście.</translation>
    </message>
    <message>
        <source>Drop chats with unknown person when I am invisible/unavailable</source>
        <translation>Ignoruj rozmowy z anonimami kiedy jestem niewidzialny/niedostępny</translation>
    </message>
    <message>
        <source>Reaction on right answer</source>
        <translation>Reakcja na poprawną odpowiedź</translation>
    </message>
</context>
<context>
    <name>Firewall</name>
    <message>
        <source>I want something</source>
        <translation>coś chcę</translation>
    </message>
    <message>
        <source>flooding DoS attack with emoticons!</source>
        <translation>atak DoS z emotikonami!</translation>
    </message>
    <message>
        <source>flooding DoS attack!</source>
        <translation>atak DoS!</translation>
    </message>
    <message>
        <source>Chat with anonim silently dropped.
</source>
        <translation>Rozmowa z anonimem po cichu odrzucona.</translation>
    </message>
    <message>
        <source>OK, now say hello, and introduce yourself ;-)</source>
        <translation>OK, teraz ładnie się przedstaw ;-)</translation>
    </message>
    <message>
        <source>User wrote right answer!
</source>
        <translation>Użytkownik udzielił prawidłowej odpowiedzi
</translation>
    </message>
    <message>
        <source>This message has been generated AUTOMATICALLY!

I&apos;m a busy person and I don&apos;t have time for stupid chats. Find another person to chat with. If you REALLY want something from me, simple type &quot;I want something&quot; (capital doesn&apos;t matter)</source>
        <translation>Ta wiadomość została wygenerowana AUTOMATYCZNIE!

Nie mam cię na mojej liście kontaktów i jeśli chcesz mi coś napisać, to wpisz po prostu &quot;coś chcę&quot; - wszystkie inne wiadomości są kasowane i nie widzę ich treści.
Jeśli chcesz natomiast &quot;poklikać&quot;, to znajdź sobie do tego inną osobę, a najlepiej zajmij się czymś pożyteczniejszym!</translation>
    </message>
    <message>
        <source>Are you sure you want to send this message?</source>
        <translation>Czy na pewno chcesz wysłać tę wiadomość?</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>&amp;Tak</translation>
    </message>
    <message>
        <source>Yes and allow until chat closed</source>
        <translation>Tak i pozwalaj dopóki prowadzisz rozmowę</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>&amp;Nie</translation>
    </message>
    <message>
        <source>%u writes</source>
        <translation>Anonim [%u] napisał</translation>
    </message>
    <message>
        <source>This message has been generated AUTOMATICALLY!

I&apos;m a busy person and I don&apos;t have time for stupid chats with the persons hiding itself. If you want to talk with me change the status to Online or Busy first.</source>
        <translation>Ta wiadomość została wygenerowana AUTOMATYCZNIE!

Jestem zajętą osobą i nie mam czasu na rozmowy z ukrywającymi się osobami. Jeśli chcesz ze mną rozmawiać, zmień wcześniej swój status na Dostępny.</translation>
    </message>
    <message>
        <source>Chat with invisible anonim ignored.
</source>
        <translation>Rozmowa z niewidocznym anonimem zignorowana.
</translation>
    </message>
    <message>
        <source>      DATA AND TIME      ::   ID      :: MESSAGE
</source>
        <translation>      DATA I CZAS      ::   ID      :: WIADOMOŚĆ
</translation>
    </message>
</context>
<context>
    <name>FirewallConfigurationUiHandler</name>
    <message>
        <source>Move to &apos;Secured&apos;</source>
        <translation>Przenieś do &apos;Zabezpieczeni&apos;</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Wszyscy</translation>
    </message>
    <message>
        <source>Move to &apos;All&apos;</source>
        <translation>Przenieś do &apos;Wszyscy&apos;</translation>
    </message>
    <message>
        <source>Secured</source>
        <translation>Zabezpieczeni</translation>
    </message>
    <message>
        <source>This message will be send to unknown person.</source>
        <translation>Ta wiadomość zostanie wysłana do nieznanej osoby.</translation>
    </message>
    <message>
        <source>Right answer for question above - you can use regexp.</source>
        <translation>Prawidłowa odpowiedź na powyższe pytanie - można używać regexp.</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>Odpowiedź:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Tekst pytania:</translation>
    </message>
</context>
<context>
    <name>FirewallNotification</name>
    <message>
        <source>Message was blocked</source>
        <translation>Wiadomość została zablokowana</translation>
    </message>
    <message>
        <source>%u writes</source>
        <translation>Anonim [%u] napisał</translation>
    </message>
</context>
</TS>

==> kadu_3.0~rc1.orig.tar.bz2: kadu-3.0-rc1/plugins/firewall/translations/firewall_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>@default</name>
    <message>
        <source>Firewall</source>
        <translation>Firewall</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Ogólne</translation>
    </message>
    <message>
        <source>Notification syntax</source>
        <translation>Składnia powiadomienia</translation>
    </message>
    <message>
        <source>%u - uin, %m - message</source>
        <translation>%u - uin, %m - wiadomość</translation>
    </message>
    <message>
        <source>Search for unknown person in directory and show window with his personal data.</source>
        <translation>Szukaj nieznanej osoby w katalogu i wyświetlaj okno z informacją o niej.</translation>
    </message>
    <message>
        <source>Unknown chats protection</source>
        <translation>Ochrona przed nieznanymi osobami</translation>
    </message>
    <message>
        <source>Ignore conferences with all persons unknown</source>
        <translation>Ignoruj konferencje, jeśli wszystkie osoby są nieznane</translation>
    </message>
    <message>
        <source>Protect against chats with unknown persons</source>
        <translation>Chroń przed rozmowami z nieznaną osobą</translation>
    </message>
    <message>
        <source>Automatic question</source>
        <translation>Automatyczne pytanie</translation>
    </message>
    <message>
        <source>Send confirmation</source>
        <translation>Wyślij potwierdzenie</translation>
    </message>
    <message>
        <source>Confirmation</source>
        <translation>Potwierdzenie</translation>
    </message>
    <message>
        <source>Safe sending</source>
        <translation>Bezpieczne wysyłanie</translation>
    </message>
    <message>
        <source>Enable safe sending</source>
        <translation>Włącz bezpieczne wysyłanie</translation>
    </message>
    <message>
        <source>You must confirm each message sent to these people</source>
        <translation>Musisz potwierdzić chęć wysłania wiadomości do tych osób</translation>
    </message>
    <message>
        <source>Message was firewalled</source>
        <translation>Wiadomość została zablokowana</translation>
    </message>
    <message>
        <source>Anonymous chat attempt</source>
        <translation>Próba nawiązania rozmowy przez anonima</translation>
    </message>
    <message>
        <source>Save anonymous chat attempt in history</source>
        <translation>Zapisuj próby nawiązania rozmowy przez anonimów w historii</translation>
    </message>
    <message>
        <source>Save anonymous chat attempt in log file</source>
        <translation>Zapisuj próby nawiązania rozmowy przez anonimów w pliku logu</translation>
    </message>
    <message>
        <source>Log file path</source>
        <translation>Ścieżka pliku logu</translation>
    </message>
    <message>
        <source>Kadu will ask the question typed below, if someone wants talk to you and you do not have him on your list.</source>
        <translation>Kadu zada poniższe pytanie osobie próbującej nawiązać rozmowę, jeżeli nie masz jej na liście.</translation>
    </message>
    <message>
        <source>Drop chats with unknown person when I am invisible/unavailable</source>
        <translation>Ignoruj rozmowy z anonimami kiedy jestem niewidzialny/niedostępny</translation>
    </message>
    <message>
        <source>Reaction on right answer</source>
        <translation>Reakcja na poprawną odpowiedź</translation>
    </message>
</context>
<context>
    <name>Firewall</name>
    <message>
        <source>I want something</source>
        <translation>coś chcę</translation>
    </message>
    <message>
        <source>flooding DoS attack with emoticons!</source>
        <translation>atak DoS z emotikonami!</translation>
    </message>
    <message>
        <source>flooding DoS attack!</source>
        <translation>atak DoS!</translation>
    </message>
    <message>
        <source>Chat with anonim silently dropped.
</source>
        <translation>Rozmowa z anonimem po cichu odrzucona.</translation>
    </message>
    <message>
        <source>OK, now say hello, and introduce yourself ;-)</source>
        <translation>OK, teraz ładnie się przedstaw ;-)</translation>
    </message>
    <message>
        <source>User wrote right answer!
</source>
        <translation>Użytkownik udzielił prawidłowej odpowiedzi
</translation>
    </message>
    <message>
        <source>This message has been generated AUTOMATICALLY!

I&apos;m a busy person and I don&apos;t have time for stupid chats. Find another person to chat with. If you REALLY want something from me, simple type &quot;I want something&quot; (capital doesn&apos;t matter)</source>
        <translation>Ta wiadomość została wygenerowana AUTOMATYCZNIE!

Nie mam cię na mojej liście kontaktów i jeśli chcesz mi coś napisać, to wpisz po prostu &quot;coś chcę&quot; - wszystkie inne wiadomości są kasowane i nie widzę ich treści.
Jeśli chcesz natomiast &quot;poklikać&quot;, to znajdź sobie do tego inną osobę, a najlepiej zajmij się czymś pożyteczniejszym!</translation>
    </message>
    <message>
        <source>Are you sure you want to send this message?</source>
        <translation>Czy na pewno chcesz wysłać tę wiadomość?</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>&amp;Tak</translation>
    </message>
    <message>
        <source>Yes and allow until chat closed</source>
        <translation>Tak i pozwalaj dopóki prowadzisz rozmowę</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>&amp;Nie</translation>
    </message>
    <message>
        <source>%u writes</source>
        <translation>Anonim [%u] napisał</translation>
    </message>
    <message>
        <source>This message has been generated AUTOMATICALLY!

I&apos;m a busy person and I don&apos;t have time for stupid chats with the persons hiding itself. If you want to talk with me change the status to Online or Busy first.</source>
        <translation>Ta wiadomość została wygenerowana AUTOMATYCZNIE!

Jestem zajętą osobą i nie mam czasu na rozmowy z ukrywającymi się osobami. Jeśli chcesz ze mną rozmawiać, zmień wcześniej swój status na Dostępny.</translation>
    </message>
    <message>
        <source>Chat with invisible anonim ignored.
</source>
        <translation>Rozmowa z niewidocznym anonimem zignorowana.
</translation>
    </message>
    <message>
        <source>      DATA AND TIME      ::   ID      :: MESSAGE
</source>
        <translation>      DATA I CZAS      ::   ID      :: WIADOMOŚĆ
</translation>
    </message>
</context>
<context>
    <name>FirewallConfigurationUiHandler</name>
    <message>
        <source>Move to &apos;Secured&apos;</source>
        <translation>Przenieś do &apos;Zabezpieczeni&apos;</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Wszyscy</translation>
    </message>
    <message>
        <source>Move to &apos;All&apos;</source>
        <translation>Przenieś do &apos;Wszyscy&apos;</translation>
    </message>
    <message>
        <source>Secured</source>
        <translation>Zabezpieczeni</translation>
    </message>
    <message>
        <source>This message will be send to unknown person.</source>
        <translation>Ta wiadomość zostanie wysłana do nieznanej osoby.</translation>
    </message>
    <message>
        <source>Right answer for question above - you can use regexp.</source>
        <translation>Prawidłowa odpowiedź na powyższe pytanie - można używać regexp.</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>Odpowiedź:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Tekst pytania:</translation>
    </message>
</context>
<context>
    <name>FirewallNotification</name>
    <message>
        <source>Message was blocked</source>
        <translation>Wiadomość została zablokowana</translation>
    </message>
    <message>
        <source>%u writes</source>
        <translation>Anonim [%u] napisał</translation>
    </message>
</context>
</TS>
